# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector_proxy_request_stats import AgentConnectorProxyRequestStats  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnectorProxyRequestStats(unittest.TestCase):
    """AgentConnectorProxyRequestStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnectorProxyRequestStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector_proxy_request_stats.AgentConnectorProxyRequestStats()  # noqa: E501
        if include_optional :
            return AgentConnectorProxyRequestStats(
                last_request_start_time = '2020-07-07T15:49:51.230Z', 
                bytes_received = 0, 
                bytes_sent = 0, 
                requests = agilicus_api.models.agent_connector_proxy_request_stats_details.AgentConnectorProxyRequestStatsDetails(
                    started = 0, 
                    finished = 0, 
                    status_1xx = 0, 
                    status_2xx = 0, 
                    status_3xx = 0, 
                    status_4xx = 0, 
                    status_5xx = 0, 
                    status_unknown = 0, 
                    failed_authentication = 0, 
                    failed_authorisation = 0, )
            )
        else :
            return AgentConnectorProxyRequestStats(
                bytes_received = 0,
                bytes_sent = 0,
                requests = agilicus_api.models.agent_connector_proxy_request_stats_details.AgentConnectorProxyRequestStatsDetails(
                    started = 0, 
                    finished = 0, 
                    status_1xx = 0, 
                    status_2xx = 0, 
                    status_3xx = 0, 
                    status_4xx = 0, 
                    status_5xx = 0, 
                    status_unknown = 0, 
                    failed_authentication = 0, 
                    failed_authorisation = 0, ),
        )

    def testAgentConnectorProxyRequestStats(self):
        """Test AgentConnectorProxyRequestStats"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
