# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.file_share_service_status import FileShareServiceStatus  # noqa: E501
from agilicus_api.rest import ApiException

class TestFileShareServiceStatus(unittest.TestCase):
    """FileShareServiceStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FileShareServiceStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.file_share_service_status.FileShareServiceStatus()  # noqa: E501
        if include_optional :
            return FileShareServiceStatus(
                share_base_app_name = '0', 
                instance_id = 'asdas9Gk4asdaTH', 
                instance_org_id = '39ddfGAaslts8qX', 
                share_uri = 'https://share-4.cloud.egov.city/'
            )
        else :
            return FileShareServiceStatus(
        )

    def testFileShareServiceStatus(self):
        """Test FileShareServiceStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
